<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="he" sourcelanguage="en">
<context>
    <name>Alert</name>
    <message>
        <source>Close (%1)</source>
        <translation>סגור (%1)</translation>
    </message>
    <message>
        <source>Collapse</source>
        <translation>צמצם</translation>
    </message>
    <message>
        <source>Expand</source>
        <translation>הרחב</translation>
    </message>
</context>
<context>
    <name>AlertLayer</name>
    <message>
        <source>Dismiss Alert</source>
        <translation>סלק אתראה</translation>
    </message>
    <message>
        <source>Ctrl+D</source>
        <translation>Ctrl+D</translation>
    </message>
</context>
<context>
    <name>DailyProgress</name>
    <message numerus="yes">
        <source>%Ln word(s)</source>
        <translation>
            <numerusform>מילה %Ln</numerusform>
            <numerusform>%Ln מילים</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%Ln minute(s)</source>
        <translation>
            <numerusform>דקה %Ln</numerusform>
            <numerusform>%Ln דקות</numerusform>
        </translation>
    </message>
    <message>
        <source>0%</source>
        <translation>0%</translation>
    </message>
    <message numerus="yes">
        <source>%L1% of %Ln minute(s)</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%L1% of %Ln word(s)</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
</context>
<context>
    <name>DailyProgressDialog</name>
    <message>
        <source>Daily Progress</source>
        <translation>התקדמות יומית</translation>
    </message>
    <message>
        <source>Longest streak</source>
        <translation>תקופה ארוכה ביותר</translation>
    </message>
    <message>
        <source>Current streak</source>
        <translation>תקופה נוכחית</translation>
    </message>
    <message>
        <source>N/A</source>
        <translation>ל/ז</translation>
    </message>
    <message numerus="yes">
        <source>%n day(s)</source>
        <translation>
            <numerusform>יום %n</numerusform>
            <numerusform>%n ימים</numerusform>
        </translation>
    </message>
    <message>
        <source>%1 &amp;ndash; %2</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DailyProgressLabel</name>
    <message>
        <source>%L1% of daily goal</source>
        <translation>%L1% מתוך היעד היומי</translation>
    </message>
</context>
<context>
    <name>DictionaryDialog</name>
    <message>
        <source>Set Language</source>
        <translation>קביעת שפה</translation>
    </message>
</context>
<context>
    <name>Document</name>
    <message>
        <source>(Untitled %1)</source>
        <translation>(ללא כותרת %1)</translation>
    </message>
    <message>
        <source>%1 (Read-Only)</source>
        <translation>%1 (קריאה-בלבד)</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>צר לי</translation>
    </message>
    <message>
        <source>Unable to save &apos;%1&apos;.</source>
        <translation>אין אפשרות לשמור &apos;%1&apos;.</translation>
    </message>
    <message>
        <source>Save File As</source>
        <translation>שמירת קובץ בשם</translation>
    </message>
    <message>
        <source>Unable to overwrite &apos;%1&apos;.</source>
        <translation>אין אפשרות להחליף את &apos;%1&apos;.</translation>
    </message>
    <message>
        <source>Rename File</source>
        <translation>שינוי שם קובץ</translation>
    </message>
    <message>
        <source>Unable to rename &apos;%1&apos;.</source>
        <translation>אין אפשרות לשנות שם &apos;%1&apos;.</translation>
    </message>
    <message>
        <source>Reload File?</source>
        <translation>לטעון מחדש קובץ?</translation>
    </message>
    <message>
        <source>Reload the file &apos;%1&apos; from disk?</source>
        <translation>לטעון מחדש קובץ &apos;%1&apos; מתוך כונן?</translation>
    </message>
    <message>
        <source>All unsaved changes will be lost.</source>
        <translation>כל השינויים שלא נשמרו יאבדו.</translation>
    </message>
    <message>
        <source>Reload</source>
        <translation>טעינה מחדש</translation>
    </message>
    <message>
        <source>Untitled %1</source>
        <translation>ללא כותרת %1</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>שאלה</translation>
    </message>
    <message>
        <source>Saving as plain text will discard all formatting. Discard formatting?</source>
        <translation>שמירה כתמליל גלוי תתעלם מכל העיצוב. האם להתעלם מן עיצוב?</translation>
    </message>
</context>
<context>
    <name>DocumentWatcher</name>
    <message>
        <source>File Changed</source>
        <translation>קובץ שונה</translation>
    </message>
    <message>
        <source>The file &apos;%1&apos; was changed by another program.</source>
        <translation>הקובץ &apos;%1&apos; שונה על ידי תוכנית אחרת.</translation>
    </message>
    <message>
        <source>Do you want to reload the file?</source>
        <translation>האם ברצונך להטעין את הקובץ מחדש?</translation>
    </message>
    <message>
        <source>Reload</source>
        <translation>טעינה מחדש</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>התעלם מן אירוע</translation>
    </message>
    <message>
        <source>File Deleted</source>
        <translation>קובץ נמחק</translation>
    </message>
    <message>
        <source>The file %1 was deleted by another program.</source>
        <translation>הקובץ %1 נמחק על ידי תוכנית אחרת.</translation>
    </message>
    <message>
        <source>Do you want to save or close the file?</source>
        <translation>האם ברצונך לשמור או לסגור את הקובץ?</translation>
    </message>
</context>
<context>
    <name>DocxReader</name>
    <message>
        <source>Unable to open archive.</source>
        <translation>אין אפשרות לפתוח ארכיון.</translation>
    </message>
</context>
<context>
    <name>FindDialog</name>
    <message>
        <source>Search for:</source>
        <translation>חפש עבור:</translation>
    </message>
    <message>
        <source>Replace with:</source>
        <translation>החלף עם:</translation>
    </message>
    <message>
        <source>Ignore case</source>
        <translation>התעלם מרישיות</translation>
    </message>
    <message>
        <source>Whole words only</source>
        <translation>כל המילים בלבד</translation>
    </message>
    <message>
        <source>Regular expressions</source>
        <translation>ביטויים רגולריים</translation>
    </message>
    <message>
        <source>Search up</source>
        <translation>חפש מעלה</translation>
    </message>
    <message>
        <source>Search down</source>
        <translation>חפש מטה</translation>
    </message>
    <message>
        <source>&amp;Find</source>
        <translation>&amp;מצא</translation>
    </message>
    <message>
        <source>&amp;Replace</source>
        <translation>&amp;החלף</translation>
    </message>
    <message>
        <source>Replace &amp;All</source>
        <translation>החלף ה&amp;כל</translation>
    </message>
    <message>
        <source>Find</source>
        <translation>מציאה</translation>
    </message>
    <message>
        <source>Replace</source>
        <translation>החלפה</translation>
    </message>
    <message numerus="yes">
        <source>Replace %n instance(s)?</source>
        <translation>
            <numerusform>להחליף מאורע %n?</numerusform>
            <numerusform>להחליף %n מאורעות?</numerusform>
        </translation>
    </message>
    <message>
        <source>Question</source>
        <translation>שאלה</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>צר לי</translation>
    </message>
    <message>
        <source>Phrase not found.</source>
        <translation>צירוף מילים לא נמצא.</translation>
    </message>
</context>
<context>
    <name>FormatManager</name>
    <message>
        <source>OpenDocument Text</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Office Open XML</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rich Text Format</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Plain Text</source>
        <translation>טקסט גלוי</translation>
    </message>
    <message>
        <source>All Files</source>
        <translation>כל הקבצים</translation>
    </message>
    <message>
        <source>All Supported Files</source>
        <translation>כל הקבצים הנתמכים</translation>
    </message>
    <message>
        <source>OpenDocument Flat XML</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Highlighter</name>
    <message>
        <source>Add</source>
        <translation>הוסף</translation>
    </message>
    <message>
        <source>Check Spelling...</source>
        <translation>בדיקת איות...</translation>
    </message>
    <message>
        <source>(No suggestions found)</source>
        <translation>(לא נמצאו הצעות)</translation>
    </message>
</context>
<context>
    <name>ImageButton</name>
    <message>
        <source>Open Image</source>
        <translation>פתוח תמונה</translation>
    </message>
    <message>
        <source>Images</source>
        <translation>תמונות</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>בחירת שפת יישום:</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;שפת מערכת&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>הערה</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>נא לאתחל את יישום זה כדי להחיל את השינוי בשפה.</translation>
    </message>
</context>
<context>
    <name>OdtReader</name>
    <message>
        <source>Unable to open archive.</source>
        <translation>אין אפשרות לפתוח ארכיון.</translation>
    </message>
</context>
<context>
    <name>PreferencesDialog</name>
    <message>
        <source>Preferences</source>
        <translation>העדפות</translation>
    </message>
    <message>
        <source>General</source>
        <translation>כללי</translation>
    </message>
    <message>
        <source>Statistics</source>
        <translation>סטטיסטיקה</translation>
    </message>
    <message>
        <source>Toolbar</source>
        <translation>סרגל כלים</translation>
    </message>
    <message>
        <source>Spell Checking</source>
        <translation>בדיקת איות</translation>
    </message>
    <message>
        <source>Select Dictionary</source>
        <translation>בחירת מילון</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>צר לי</translation>
    </message>
    <message>
        <source>Unable to open archive.</source>
        <translation>אין אפשרות לפתוח ארכיון.</translation>
    </message>
    <message>
        <source>The archive does not contain a usable dictionary.</source>
        <translation>הארכיון לא מכיל מילון שמיש.</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>שאלה</translation>
    </message>
    <message>
        <source>Shortcuts</source>
        <translation>קיצורי דרך</translation>
    </message>
    <message>
        <source>One or more shortcuts conflict. Do you wish to proceed?</source>
        <translation>מתנגשים קיצור דרך אחד או יותר. האם ברצונך להמשיך?</translation>
    </message>
    <message>
        <source>The dictionary &quot;%1&quot; already exists. Do you want to replace it?</source>
        <translation>המילון &quot;%1&quot; כבר קיים. האם ברצונך להחליפו?</translation>
    </message>
    <message>
        <source>Daily Goal</source>
        <translation>יעד יומי</translation>
    </message>
    <message>
        <source>None</source>
        <translation>בלי</translation>
    </message>
    <message>
        <source>Minutes:</source>
        <translation>דקות:</translation>
    </message>
    <message>
        <source>Words:</source>
        <translation>מילים:</translation>
    </message>
    <message>
        <source>Editing</source>
        <translation>עריכה</translation>
    </message>
    <message>
        <source>Always vertically center</source>
        <translation>תמיד ממורכז במאונך</translation>
    </message>
    <message>
        <source>Block insertion cursor</source>
        <translation>סמן שיבוץ בלוק</translation>
    </message>
    <message>
        <source>Smooth fonts</source>
        <translation>גופנים מלוטשים</translation>
    </message>
    <message>
        <source>Typewriter sounds</source>
        <translation>צלילי מכונת כתיבה</translation>
    </message>
    <message>
        <source>Smart quotes:</source>
        <translation>מרכאות חכמות:</translation>
    </message>
    <message>
        <source>Double</source>
        <translation>כפולות</translation>
    </message>
    <message>
        <source>Single</source>
        <translation>בודדות</translation>
    </message>
    <message>
        <source>Scenes</source>
        <translation>מקטעים</translation>
    </message>
    <message>
        <source>Divider:</source>
        <translation>מפריד:</translation>
    </message>
    <message>
        <source>Saving</source>
        <translation>שמירה</translation>
    </message>
    <message>
        <source>Remember cursor position</source>
        <translation>זכור מיקום סמן</translation>
    </message>
    <message>
        <source>Word count</source>
        <translation>ספור מילים</translation>
    </message>
    <message>
        <source>Page count</source>
        <translation>ספור עמודים</translation>
    </message>
    <message>
        <source>Paragraph count</source>
        <translation>ספור פסקאות</translation>
    </message>
    <message>
        <source>Character count</source>
        <translation>ספור תווים</translation>
    </message>
    <message>
        <source>Characters:</source>
        <translation>תווים:</translation>
    </message>
    <message>
        <source>Paragraphs:</source>
        <translation>פסקאות:</translation>
    </message>
    <message>
        <source>Word Count Algorithm</source>
        <translation>אלגוריתם ספירת מילים</translation>
    </message>
    <message>
        <source>Reset daily progress for today to zero?</source>
        <translation>לאפס התקדמות יומית להיום אל אפס?</translation>
    </message>
    <message>
        <source>Write byte order mark in plain text files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Default format:</source>
        <translation>פורמט ברירת מחדל:</translation>
    </message>
    <message>
        <source>Reset Today</source>
        <translation>איפוס היום</translation>
    </message>
    <message>
        <source>History</source>
        <translation>היסטוריה</translation>
    </message>
    <message>
        <source>Remember history</source>
        <translation>זכור היסטוריה</translation>
    </message>
    <message>
        <source>Show streaks</source>
        <translation>הצג תקופות</translation>
    </message>
    <message>
        <source>Minimum progress for streaks:</source>
        <translation>התקדמות נומינלית לתקופות:</translation>
    </message>
    <message>
        <source>Detect word boundaries</source>
        <translation>אתר גבולות מילה</translation>
    </message>
    <message>
        <source>Divide character count by six</source>
        <translation>חלק ספירת תו בשש (6)</translation>
    </message>
    <message>
        <source>Count each letter as a word</source>
        <translation>ספור כל אות כאילו היתה מילה</translation>
    </message>
    <message>
        <source>Page Count Algorithm</source>
        <translation>אלגוריתם ספירת עמוד</translation>
    </message>
    <message>
        <source>Style</source>
        <translation>סגנון</translation>
    </message>
    <message>
        <source>Icons Only</source>
        <translation>צלמיות בלבד</translation>
    </message>
    <message>
        <source>Text Only</source>
        <translation>תמליל בלבד</translation>
    </message>
    <message>
        <source>Text Alongside Icons</source>
        <translation>תמליל לצד צלמיות</translation>
    </message>
    <message>
        <source>Text Under Icons</source>
        <translation>תמליל תחת צלמיות</translation>
    </message>
    <message>
        <source>Text Position:</source>
        <translation>מיקום תמליל:</translation>
    </message>
    <message>
        <source>Actions</source>
        <translation>פעולות</translation>
    </message>
    <message>
        <source>Move Up</source>
        <translation>הזז מעלה</translation>
    </message>
    <message>
        <source>Move Down</source>
        <translation>הזז מטה</translation>
    </message>
    <message>
        <source>Add Separator</source>
        <translation>הוסף חוצץ</translation>
    </message>
    <message>
        <source>Command</source>
        <translation>פקודה</translation>
    </message>
    <message>
        <source>Shortcut</source>
        <translation>קיצור דרך</translation>
    </message>
    <message>
        <source>Action</source>
        <translation>פעולה</translation>
    </message>
    <message>
        <source>Check spelling as you type</source>
        <translation>בדוק איות בעת הקלדה</translation>
    </message>
    <message>
        <source>Ignore words in UPPERCASE</source>
        <translation>התעלם ממילים עיליות</translation>
    </message>
    <message>
        <source>Ignore words with numbers</source>
        <translation>התעלם ממילים עם אותיות</translation>
    </message>
    <message>
        <source>Language</source>
        <translation>שפה</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>הוסף</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>הסר</translation>
    </message>
    <message>
        <source>Personal Dictionary</source>
        <translation>מילון אישי</translation>
    </message>
    <message>
        <source>Remove current dictionary?</source>
        <translation>להסיר מילון נוכחי?</translation>
    </message>
    <message>
        <source>User Interface</source>
        <translation>ממשק משתמש</translation>
    </message>
    <message>
        <source>Always show scrollbar</source>
        <translation>הצג תמיד פס גלילה</translation>
    </message>
    <message>
        <source>Always show top bar</source>
        <translation>הצג תמיד סרגל עליון</translation>
    </message>
    <message>
        <source>Always show bottom bar</source>
        <translation>הצג תמיד סרגל תחתון</translation>
    </message>
</context>
<context>
    <name>RtfReader</name>
    <message>
        <source>Not a supported RTF file.</source>
        <translation>לא קובץ RTF נתמך.</translation>
    </message>
</context>
<context>
    <name>RtfTokenizer</name>
    <message>
        <source>Unexpectedly reached end of file.</source>
        <translation>הגיע באופן מפתיע לסוף קובץ.</translation>
    </message>
</context>
<context>
    <name>SceneList</name>
    <message>
        <source>Ctrl+Shift+Down</source>
        <translation>Ctrl+Shift+מטה</translation>
    </message>
    <message>
        <source>Move Scenes Up</source>
        <translation>הזז מקטעים מעלה</translation>
    </message>
    <message>
        <source>Ctrl+Shift+Up</source>
        <translation>Ctrl+Shift+מעלה</translation>
    </message>
    <message>
        <source>Toggle Scene List</source>
        <translation>הצג/הסתר רשימת מקטע</translation>
    </message>
    <message>
        <source>Shift+F4</source>
        <translation>Shift+F4</translation>
    </message>
    <message>
        <source>Show scene list (%1)</source>
        <translation>הצג רשימת מקטע (%1)</translation>
    </message>
    <message>
        <source>Hide scene list (%1)</source>
        <translation>הסתר רשימת מקטע (%1)</translation>
    </message>
    <message>
        <source>Filter</source>
        <translation>סינון</translation>
    </message>
    <message>
        <source>Move Scenes Down</source>
        <translation>הזז מקטעים מטה</translation>
    </message>
    <message>
        <source>Resize scene list</source>
        <translation>שנה גודל רשימת מקטע</translation>
    </message>
</context>
<context>
    <name>Session</name>
    <message>
        <source>Default</source>
        <translation>ברירת מחדל</translation>
    </message>
</context>
<context>
    <name>SessionManager</name>
    <message>
        <source>Manage Sessions</source>
        <translation>ניהול סשנים</translation>
    </message>
    <message>
        <source>S&amp;essions</source>
        <translation>ס&amp;שנים</translation>
    </message>
    <message>
        <source>New</source>
        <translation>חדש</translation>
    </message>
    <message>
        <source>Duplicate</source>
        <translation>שכפל</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>שנה שם</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>מחק</translation>
    </message>
    <message>
        <source>Switch To</source>
        <translation>החלף אל</translation>
    </message>
    <message>
        <source>New Session</source>
        <translation>סשן חדש</translation>
    </message>
    <message>
        <source>Duplicate Session</source>
        <translation>שכפול סשן</translation>
    </message>
    <message>
        <source>Rename Session</source>
        <translation>שינוי שם סשן</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>שאלה</translation>
    </message>
    <message>
        <source>Delete selected session?</source>
        <translation>למחוק סשן נבחר?</translation>
    </message>
    <message>
        <source>Session name:</source>
        <translation>שם סשן:</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>צר לי</translation>
    </message>
    <message>
        <source>The requested session name is already in use.</source>
        <translation>שם הסשן המבוקש כבר מצוי בשימוש.</translation>
    </message>
    <message>
        <source>&amp;New...</source>
        <translation>&amp;חדש...</translation>
    </message>
    <message>
        <source>Ctrl+Shift+N</source>
        <translation>Ctrl+Shift+N</translation>
    </message>
    <message>
        <source>&amp;Manage...</source>
        <translation>&amp;ניהול...</translation>
    </message>
    <message>
        <source>Ctrl+Shift+M</source>
        <translation>Ctrl+Shift+M</translation>
    </message>
</context>
<context>
    <name>ShortcutEdit</name>
    <message>
        <source>Clear</source>
        <translation>טהר</translation>
    </message>
    <message>
        <source>Reset to Default</source>
        <translation>אפס</translation>
    </message>
    <message>
        <source>Shortcut:</source>
        <translation>קיצור דרך:</translation>
    </message>
</context>
<context>
    <name>SmartQuote</name>
    <message>
        <source>Replacing quotation marks...</source>
        <translation>מחליף כעת סימני מרכאות...</translation>
    </message>
    <message>
        <source>Please Wait</source>
        <translation>נא להמתין</translation>
    </message>
</context>
<context>
    <name>SpellChecker</name>
    <message>
        <source>Check Spelling</source>
        <translation>בדיקת איות</translation>
    </message>
    <message>
        <source>&amp;Add</source>
        <translation>הו&amp;סף</translation>
    </message>
    <message>
        <source>&amp;Ignore</source>
        <translation>הת&amp;עלם</translation>
    </message>
    <message>
        <source>I&amp;gnore All</source>
        <translation>התעלם מ&amp;הכל</translation>
    </message>
    <message>
        <source>&amp;Change</source>
        <translation>&amp;שנה</translation>
    </message>
    <message>
        <source>C&amp;hange All</source>
        <translation>שנה ה&amp;כל</translation>
    </message>
    <message>
        <source>Not in dictionary:</source>
        <translation>לא במילון:</translation>
    </message>
    <message>
        <source>Change to:</source>
        <translation>שנה אל:</translation>
    </message>
    <message>
        <source>Checking spelling...</source>
        <translation>בודק כעת איות...</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>ביטול</translation>
    </message>
    <message>
        <source>Please wait</source>
        <translation>נא להמתין</translation>
    </message>
    <message>
        <source>Continue checking at beginning of file?</source>
        <translation>להמשיך לבדוק בתחילתו של קובץ?</translation>
    </message>
    <message>
        <source>Spell check complete.</source>
        <translation>בדיקת איות הושלמה.</translation>
    </message>
</context>
<context>
    <name>SymbolsDialog</name>
    <message>
        <source>Symbols</source>
        <translation>סמלים</translation>
    </message>
    <message>
        <source>Recently used symbols</source>
        <translation>סמלים שנשתמשו לאחרונה</translation>
    </message>
    <message>
        <source>All symbols</source>
        <translation>כל הסמלים</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>פרטים</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation>שם:</translation>
    </message>
    <message>
        <source>Insert</source>
        <translation>שבץ</translation>
    </message>
</context>
<context>
    <name>SymbolsModel</name>
    <message>
        <source>Blocks</source>
        <translation>בלוקים</translation>
    </message>
    <message>
        <source>Scripts</source>
        <translation>תסריטים</translation>
    </message>
</context>
<context>
    <name>Theme</name>
    <message>
        <source>Untitled %1</source>
        <translation>ללא כותרת %1</translation>
    </message>
</context>
<context>
    <name>ThemeDialog</name>
    <message>
        <source>Name:</source>
        <translation>שם:</translation>
    </message>
    <message>
        <source>No Image</source>
        <translation>אין תמונה</translation>
    </message>
    <message>
        <source>Tiled</source>
        <translation>מרוצף</translation>
    </message>
    <message>
        <source>Centered</source>
        <translation>ממורכז</translation>
    </message>
    <message>
        <source>Stretched</source>
        <translation>פרוש</translation>
    </message>
    <message>
        <source>Scaled</source>
        <translation>מתוח</translation>
    </message>
    <message>
        <source>Zoomed</source>
        <translation>מוקרב</translation>
    </message>
    <message>
        <source>Opacity:</source>
        <translation>עמימות:</translation>
    </message>
    <message>
        <source>Position:</source>
        <translation>מיקום:</translation>
    </message>
    <message>
        <source>Width:</source>
        <translation>רוחב:</translation>
    </message>
    <message>
        <source>Round Text Background Corners</source>
        <translation>פינות רקע טקסט מעוגלות</translation>
    </message>
    <message>
        <source>Radius:</source>
        <translation>רדיוס:</translation>
    </message>
    <message>
        <source>Blur Text Background</source>
        <translation>רקע טקסט מטושטש</translation>
    </message>
    <message>
        <source>Text Background Drop Shadow</source>
        <translation>רקע טקסט עם הצלה</translation>
    </message>
    <message>
        <source>Vertical Offset:</source>
        <translation>הדפסה אנכית:</translation>
    </message>
    <message>
        <source>Margins</source>
        <translation>שוליים</translation>
    </message>
    <message>
        <source>Window:</source>
        <translation>חלון:</translation>
    </message>
    <message>
        <source>Page:</source>
        <translation>עמוד:</translation>
    </message>
    <message>
        <source>Indent first line</source>
        <translation>הזח שורה ראשונה</translation>
    </message>
    <message>
        <source>Above:</source>
        <translation>מעלה:</translation>
    </message>
    <message>
        <source>Below:</source>
        <translation>מטה:</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>הסר</translation>
    </message>
    <message>
        <source>Edit Theme</source>
        <translation>עריכת מוטיב</translation>
    </message>
    <message>
        <source>Window Background</source>
        <translation>רקע חלון</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation>טיפוס:</translation>
    </message>
    <message>
        <source>Color:</source>
        <translation>צבע:</translation>
    </message>
    <message>
        <source>Image:</source>
        <translation>תמונה:</translation>
    </message>
    <message>
        <source> pixels</source>
        <translation>פיקסלים</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>שמאל</translation>
    </message>
    <message>
        <source>Text Background</source>
        <translation>רקע טקסט</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>ימין</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>תמליל</translation>
    </message>
    <message>
        <source>Font:</source>
        <translation>גופן:</translation>
    </message>
    <message>
        <source>Misspelled:</source>
        <translation>שגיאת כתיב:</translation>
    </message>
    <message>
        <source>Line Spacing</source>
        <translation>ריווח שורה</translation>
    </message>
    <message>
        <source>Single</source>
        <translation>בודדות</translation>
    </message>
    <message>
        <source>1.5 Lines</source>
        <translation>1.5 שורות</translation>
    </message>
    <message>
        <source>Double</source>
        <translation>כפולות</translation>
    </message>
    <message>
        <source>Proportional</source>
        <translation>פרופורציונלי</translation>
    </message>
    <message>
        <source>Height:</source>
        <translation>גובה:</translation>
    </message>
    <message>
        <source>Paragraph Spacing</source>
        <translation>ריווח פסקאות</translation>
    </message>
    <message>
        <source>Tab Width:</source>
        <translation>רוחב כרטיסייה:</translation>
    </message>
    <message>
        <source>New Theme</source>
        <translation>מוטיב חדש</translation>
    </message>
</context>
<context>
    <name>ThemeManager</name>
    <message>
        <source>Themes</source>
        <translation>מוטיבים</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>ברירת מחדל</translation>
    </message>
    <message>
        <source>Gentle Blues</source>
        <translation>כחולים עדינים</translation>
    </message>
    <message>
        <source>Old School</source>
        <translation>בית ספר ותיק</translation>
    </message>
    <message>
        <source>Space Dreams</source>
        <translation>פנטזיות חלל</translation>
    </message>
    <message>
        <source>Writing Desk</source>
        <translation>שולחן כתיבה</translation>
    </message>
    <message>
        <source>New</source>
        <translation>חדש</translation>
    </message>
    <message>
        <source>Duplicate</source>
        <translation>שכפל</translation>
    </message>
    <message>
        <source>Custom</source>
        <translation>מותאם</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>ערוך</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>מחק</translation>
    </message>
    <message>
        <source>Import</source>
        <translation>יבא</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>יצא</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>שאלה</translation>
    </message>
    <message>
        <source>Delete theme &apos;%1&apos;?</source>
        <translation>למחוק את מוטיב &apos;%1&apos;?</translation>
    </message>
    <message>
        <source>Themes (%1)</source>
        <translation>מוטיבים (%1)</translation>
    </message>
    <message>
        <source>Import Theme</source>
        <translation>ייבוא מוטיב</translation>
    </message>
    <message>
        <source>Export Theme</source>
        <translation>ייצוא מוטיב</translation>
    </message>
    <message>
        <source>Bitter Skies</source>
        <translation>שמים מרים</translation>
    </message>
    <message>
        <source>Enchantment</source>
        <translation>קסם</translation>
    </message>
    <message>
        <source>Spy Games</source>
        <translation>משחקי ריגול</translation>
    </message>
    <message>
        <source>Tranquility</source>
        <translation>שלווה</translation>
    </message>
</context>
<context>
    <name>Timer</name>
    <message>
        <source>&lt;b&gt;%1&lt;/b&gt; - %2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Question</source>
        <translation>שאלה</translation>
    </message>
    <message>
        <source>Delete timer?</source>
        <translation>למחוק שעון עצר?</translation>
    </message>
    <message>
        <source>&lt;b&gt;Words:&lt;/b&gt; %L1</source>
        <translation>&lt;b&gt;מילים:&lt;/b&gt; %L1</translation>
    </message>
    <message>
        <source>&lt;b&gt;Pages:&lt;/b&gt; %L1</source>
        <translation>&lt;b&gt;עמודים:&lt;/b&gt; %L1</translation>
    </message>
    <message>
        <source>&lt;b&gt;Paragraphs:&lt;/b&gt; %L1</source>
        <translation>&lt;b&gt;פסקאות:&lt;/b&gt; %L1</translation>
    </message>
    <message>
        <source>&lt;b&gt;Characters:&lt;/b&gt; %L1 / %L2</source>
        <translation>&lt;b&gt;תווים:&lt;/b&gt; %L1 / %L2</translation>
    </message>
    <message>
        <source>Set Delay</source>
        <translation>הגדר שיהוי</translation>
    </message>
    <message>
        <source>Set Time</source>
        <translation>הגדר זמן</translation>
    </message>
    <message>
        <source>Delay:</source>
        <translation>שיהוי:</translation>
    </message>
    <message>
        <source>Time:</source>
        <translation>זמן:</translation>
    </message>
    <message>
        <source>HH:mm:ss</source>
        <translation>HH:mm:ss</translation>
    </message>
    <message>
        <source>Alarm</source>
        <translation>אזעקה</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation>טיפוס:</translation>
    </message>
    <message>
        <source>Memo:</source>
        <translation>מזכר:</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>ערוך</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>מחק</translation>
    </message>
</context>
<context>
    <name>TimerDisplay</name>
    <message>
        <source>HH:mm:ss</source>
        <translation>HH:mm:ss</translation>
    </message>
    <message>
        <source>No timers running</source>
        <translation>אין שעון עצר שמורץ</translation>
    </message>
</context>
<context>
    <name>TimerManager</name>
    <message>
        <source>Timers</source>
        <translation>שעוני עצר</translation>
    </message>
    <message>
        <source>New</source>
        <translation>חדש</translation>
    </message>
    <message>
        <source>Recent</source>
        <translation>אחרונים</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>שאלה</translation>
    </message>
    <message>
        <source>Cancel editing timers?</source>
        <translation>ביטול עריכת שעוני עצר?</translation>
    </message>
    <message>
        <source>+HH:mm:ss</source>
        <translation>+HH:mm:ss</translation>
    </message>
    <message>
        <source>%1 - %2</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>Loading themes</source>
        <translation>מטעין כעת מוטיבים</translation>
    </message>
    <message>
        <source>Loading sounds</source>
        <translation>מטעין כעת צלילים</translation>
    </message>
    <message>
        <source>Untitled</source>
        <translation>ללא כותרת</translation>
    </message>
    <message>
        <source>Open File</source>
        <translation>פתיחת קובץ</translation>
    </message>
    <message>
        <source>About FocusWriter</source>
        <translation>אדות ‫FocusWriter</translation>
    </message>
    <message>
        <source>FocusWriter</source>
        <translation>‫FocusWriter</translation>
    </message>
    <message>
        <source>A simple fullscreen word processor</source>
        <translation>עורך תמלילים פשוט במסך מלא</translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2008-%1 Graeme Gott</source>
        <translation>Copyright &amp;copy; 2008-%1 Graeme Gott</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
        <translation>משוחרר תחת הרשיון ‫&lt;a href=%1&gt;GPL 3&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Uses icons from the &lt;a href=%1&gt;Oxygen&lt;/a&gt; icon theme</source>
        <translation>הצלמיות נלקחו מן הפרויקט &lt;a href=%1&gt;Oxygen&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Used under the &lt;a href=%1&gt;LGPL 3&lt;/a&gt; license</source>
        <translation>בשימוש תחת הרשיון &lt;a href=%1&gt;LGPL 3&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Characters: %L1 / %L2</source>
        <translation>תווים: %L1 / %L2</translation>
    </message>
    <message>
        <source>Pages: %L1</source>
        <translation>עמודים: %L1</translation>
    </message>
    <message>
        <source>Paragraphs: %L1</source>
        <translation>פסקאות: %L1</translation>
    </message>
    <message>
        <source>Words: %L1</source>
        <translation>מילים: %L1</translation>
    </message>
    <message>
        <source>Opening %1</source>
        <translation>‫‭%1‬ נפתח כעת</translation>
    </message>
    <message>
        <source>(Untitled %1)</source>
        <translation>(ללא כותרת %1)</translation>
    </message>
    <message>
        <source>List all documents</source>
        <translation>מנה את כל המסמכים</translation>
    </message>
    <message>
        <source>Switch to Next Document</source>
        <translation>עבור אל מסמך בא</translation>
    </message>
    <message>
        <source>Switch to Previous Document</source>
        <translation>עבור אל מסמך קודם</translation>
    </message>
    <message>
        <source>Switch to First Document</source>
        <translation>עבור אל מסמך ראשון</translation>
    </message>
    <message>
        <source>Switch to Last Document</source>
        <translation>עבור אל מסמך אחרון</translation>
    </message>
    <message>
        <source>Switch to Document %1</source>
        <translation>עבור אל מסמך %1</translation>
    </message>
    <message>
        <source>Loading settings</source>
        <translation>טוען כעת הגדרות</translation>
    </message>
    <message>
        <source>Emergency cache is not writable.</source>
        <translation>מטמון חירום אינו בר כתיבה.</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>אזהרה</translation>
    </message>
    <message>
        <source>FocusWriter was not shut down cleanly.</source>
        <translation>‫FocusWriter לא סוים באופן מוסדר.</translation>
    </message>
    <message>
        <source>Restore from the emergency cache?</source>
        <translation>לשחזר מתוך מטמון חירום?</translation>
    </message>
    <message>
        <source>Some files could not be opened.</source>
        <translation>קבצים מסוימים לא יכלו להיפתח.</translation>
    </message>
    <message>
        <source>Some files were opened Read-Only.</source>
        <translation>קבצים מסוימים נפתחו לקריאה-בלבד.</translation>
    </message>
    <message>
        <source>&apos;%1&apos; is newer than the cached copy.</source>
        <translation>&apos;%1&apos; הינו חדש יותר מן העותק המוטמן.</translation>
    </message>
    <message>
        <source>Overwrite newer file?</source>
        <translation>להחליף קובץ חדש?</translation>
    </message>
    <message>
        <source>Save Changes?</source>
        <translation>לשמור שינויים?</translation>
    </message>
    <message>
        <source>Save changes to the file &apos;%1&apos; before closing?</source>
        <translation>לשמור שינויים לתוך הקובץ &apos;%1&apos; טרם סגירה?</translation>
    </message>
    <message>
        <source>Your changes will be lost if you don&apos;t save them.</source>
        <translation>השינויים שלך יאבדו אם לא תשמור אותם.</translation>
    </message>
    <message>
        <source>Unable to load typewriter sounds.</source>
        <translation>אין אפשרות לטעון צלילי מכונת כתיבה.</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;קובץ</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;חדש</translation>
    </message>
    <message>
        <source>&amp;Open...</source>
        <translation>&amp;פתיחה...</translation>
    </message>
    <message>
        <source>Reloa&amp;d</source>
        <translation>&amp;טען מחדש</translation>
    </message>
    <message>
        <source>&amp;Save</source>
        <translation>&amp;שמור</translation>
    </message>
    <message>
        <source>Save &amp;As...</source>
        <translation>שמירה &amp;בשם...</translation>
    </message>
    <message>
        <source>&amp;Rename...</source>
        <translation>שי&amp;נוי שם...</translation>
    </message>
    <message>
        <source>Save A&amp;ll</source>
        <translation>שמור ה&amp;כל</translation>
    </message>
    <message>
        <source>Manage Sessions</source>
        <translation>נהל סשנים</translation>
    </message>
    <message>
        <source>New Session</source>
        <translation>סשן חדש</translation>
    </message>
    <message>
        <source>&amp;Print...</source>
        <translation>ה&amp;דפסה...</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;סגור</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>י&amp;ציאה</translation>
    </message>
    <message>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>ע&amp;ריכה</translation>
    </message>
    <message>
        <source>&amp;Undo</source>
        <translation>בט&amp;ל</translation>
    </message>
    <message>
        <source>&amp;Redo</source>
        <translation>ב&amp;צע שוב</translation>
    </message>
    <message>
        <source>Cu&amp;t</source>
        <translation>&amp;גזור</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>הע&amp;תק</translation>
    </message>
    <message>
        <source>&amp;Paste</source>
        <translation>ה&amp;דבק</translation>
    </message>
    <message>
        <source>Paste &amp;Unformatted</source>
        <translation>הדבק בלי &amp;עיצוב</translation>
    </message>
    <message>
        <source>Ctrl+Shift+V</source>
        <translation>Ctrl+Shift+V</translation>
    </message>
    <message>
        <source>Select &amp;All</source>
        <translation>בחר ה&amp;כל</translation>
    </message>
    <message>
        <source>Select &amp;Scene</source>
        <translation>בחר &amp;מקטע</translation>
    </message>
    <message>
        <source>Ctrl+Shift+A</source>
        <translation>Ctrl+Shift+A</translation>
    </message>
    <message>
        <source>Fo&amp;rmat</source>
        <translation>עי&amp;צוב</translation>
    </message>
    <message>
        <source>&amp;Bold</source>
        <translation>&amp;מודגש</translation>
    </message>
    <message>
        <source>&amp;Italic</source>
        <translation>&amp;נטוי</translation>
    </message>
    <message>
        <source>&amp;Underline</source>
        <translation>&amp;קו תחתון</translation>
    </message>
    <message>
        <source>Stri&amp;kethrough</source>
        <translation>קו &amp;חוצה</translation>
    </message>
    <message>
        <source>Ctrl+K</source>
        <translation>Ctrl+K</translation>
    </message>
    <message>
        <source>Sup&amp;erscript</source>
        <translation>כיתוב &amp;עילי</translation>
    </message>
    <message>
        <source>Ctrl+^</source>
        <translation>Ctrl+^</translation>
    </message>
    <message>
        <source>&amp;Subscript</source>
        <translation>כיתוב &amp;תחתי</translation>
    </message>
    <message>
        <source>Ctrl+_</source>
        <translation>Ctrl+_</translation>
    </message>
    <message>
        <source>Align &amp;Left</source>
        <translation>יישור &amp;שמאל</translation>
    </message>
    <message>
        <source>Ctrl+{</source>
        <translation>Ctrl+{</translation>
    </message>
    <message>
        <source>Align &amp;Center</source>
        <translation>יישור מ&amp;רכז</translation>
    </message>
    <message>
        <source>Ctrl+|</source>
        <translation>Ctrl+|</translation>
    </message>
    <message>
        <source>Align &amp;Right</source>
        <translation>יישור &amp;ימין</translation>
    </message>
    <message>
        <source>Ctrl+}</source>
        <translation>Ctrl+}</translation>
    </message>
    <message>
        <source>Align &amp;Justify</source>
        <translation>יישור מ&amp;אוזן</translation>
    </message>
    <message>
        <source>Ctrl+J</source>
        <translation>Ctrl+J</translation>
    </message>
    <message>
        <source>&amp;Decrease Indent</source>
        <translation>&amp;צמצם שוליים</translation>
    </message>
    <message>
        <source>Ctrl+&lt;</source>
        <translation>Ctrl+&lt;</translation>
    </message>
    <message>
        <source>I&amp;ncrease Indent</source>
        <translation>&amp;גידול שוליים</translation>
    </message>
    <message>
        <source>Ctrl+&gt;</source>
        <translation>Ctrl+&gt;</translation>
    </message>
    <message>
        <source>Le&amp;ft to Right Block</source>
        <translation>בלוק שמ&amp;אל אל ימין</translation>
    </message>
    <message>
        <source>Ri&amp;ght to Left Block</source>
        <translation>בלוק י&amp;מין אל שמאל</translation>
    </message>
    <message>
        <source>&amp;Tools</source>
        <translation>&amp;כלים</translation>
    </message>
    <message>
        <source>&amp;Find...</source>
        <translation>&amp;חיפוש...</translation>
    </message>
    <message>
        <source>Find &amp;Next</source>
        <translation>מצא את ה&amp;בא</translation>
    </message>
    <message>
        <source>Find Pre&amp;vious</source>
        <translation>מצא את ה&amp;קודם</translation>
    </message>
    <message>
        <source>&amp;Replace...</source>
        <translation>&amp;החלפה...</translation>
    </message>
    <message>
        <source>Ctrl+R</source>
        <translation>Ctrl+R</translation>
    </message>
    <message>
        <source>Smart &amp;Quotes</source>
        <translation>מר&amp;כאות חכמות</translation>
    </message>
    <message>
        <source>Update &amp;Document</source>
        <translation>עדכן &amp;מסמך</translation>
    </message>
    <message>
        <source>Update &amp;Selection</source>
        <translation>עדכן &amp;בחירה</translation>
    </message>
    <message>
        <source>&amp;Spelling...</source>
        <translation>&amp;איות...</translation>
    </message>
    <message>
        <source>F7</source>
        <translation>F7</translation>
    </message>
    <message>
        <source>Set &amp;Language...</source>
        <translation>קביעת &amp;שפה...</translation>
    </message>
    <message>
        <source>&amp;Timers...</source>
        <translation>&amp;שעוני עצר...</translation>
    </message>
    <message>
        <source>S&amp;ymbols...</source>
        <translation>&amp;סמלים...</translation>
    </message>
    <message>
        <source>&amp;Daily Progress</source>
        <translation>התקדמות &amp;יומית</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;הגדרות</translation>
    </message>
    <message>
        <source>Show &amp;Toolbar</source>
        <translation>הצג &amp;סרגל כלים</translation>
    </message>
    <message>
        <source>Show &amp;Menu Icons</source>
        <translation>הצג &amp;צלמיות תפריט</translation>
    </message>
    <message>
        <source>F&amp;ocused Text</source>
        <translation>תמליל ממור&amp;כז</translation>
    </message>
    <message>
        <source>&amp;Fullscreen</source>
        <translation>&amp;מסך מלא</translation>
    </message>
    <message>
        <source>F11</source>
        <translation>F11</translation>
    </message>
    <message>
        <source>Esc</source>
        <translation>Esc</translation>
    </message>
    <message>
        <source>M&amp;inimize</source>
        <translation>מ&amp;זער</translation>
    </message>
    <message>
        <source>Ctrl+M</source>
        <translation>Ctrl+M</translation>
    </message>
    <message>
        <source>&amp;Themes...</source>
        <translation>מו&amp;טיבים...</translation>
    </message>
    <message>
        <source>&amp;Preferences...</source>
        <translation>&amp;העדפות...</translation>
    </message>
    <message>
        <source>Focus Off</source>
        <translation>בטל מרכוז</translation>
    </message>
    <message>
        <source>Focus One Line</source>
        <translation>מרכז שורה אחת</translation>
    </message>
    <message>
        <source>Focus Three Lines</source>
        <translation>מרכז שלוש שורות</translation>
    </message>
    <message>
        <source>&amp;Paragraph</source>
        <translation>&amp;פסקה</translation>
    </message>
    <message>
        <source>Focus Paragraph</source>
        <translation>מרכז פסקה</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;עזרה</translation>
    </message>
    <message>
        <source>Application &amp;Language...</source>
        <translation>&amp;שפת יישום...</translation>
    </message>
    <message>
        <source>Some files were unsupported and could not be opened.</source>
        <translation>קבצים מסוימים לא נתמכו ולא היתה אפשרות לפתוח אותם.</translation>
    </message>
    <message>
        <source>&amp;Off</source>
        <translation>&amp;כבוי</translation>
    </message>
    <message>
        <source>One &amp;Line</source>
        <translation>שורה &amp;אחת</translation>
    </message>
    <message>
        <source>&amp;Three Lines</source>
        <translation>&amp;שלוש שורות</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;אודות</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>אודות &amp;Qt</translation>
    </message>
    <message>
        <source>Pa&amp;ge Setup...</source>
        <translation>ת&amp;צורת עמוד...</translation>
    </message>
    <message>
        <source>&amp;Heading</source>
        <translation>&amp;כותרת</translation>
    </message>
    <message>
        <source>Heading &amp;1</source>
        <translation>כותרת &amp;1</translation>
    </message>
    <message>
        <source>Heading &amp;2</source>
        <translation>כותרת &amp;2</translation>
    </message>
    <message>
        <source>Heading &amp;3</source>
        <translation>כותרת &amp;3</translation>
    </message>
    <message>
        <source>Heading &amp;4</source>
        <translation>כותרת &amp;4</translation>
    </message>
    <message>
        <source>Heading &amp;5</source>
        <translation>כותרת &amp;5</translation>
    </message>
    <message>
        <source>Heading &amp;6</source>
        <translation>כותרת &amp;6</translation>
    </message>
    <message>
        <source>&amp;Normal</source>
        <translation>&amp;רגיל</translation>
    </message>
    <message>
        <source>Update Document Smart Quotes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Update Selection Smart Quotes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+Shift+`</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <source>Files to open in current session.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
